import 'package:cs_resources/constants/color_constants.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shared/utils/date_time_utils.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/my_text_view.dart';

import 'labour_request_controller.dart';

import 'package:plugin_basic/base/base_stateless_page.dart';
import 'package:plugin_basic/utils/ext_get_nav.dart';
import 'package:router/path/router_path.dart';

import 'labour_request_item.dart';
import 'labour_request_state.dart';

class LabourRequestPage extends BaseStatelessPage<LabourRequestController> {
  LabourRequestPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance() {
    return Get.start(RouterPath.labourRequestSG);
  }

  late LabourRequestState state;

  @override
  void initState() {
    state = controller.state;
  }

  @override
  LabourRequestController createRawController() {
    return LabourRequestController();
  }

  @override
  Widget buildWidget(BuildContext context) {
    return autoCtlGetBuilder(builder: (controller) {
      return Scaffold(
        extendBodyBehindAppBar: true,
        appBar: MyAppBar.appBar(context, "Labour Request".tr),
        body: SafeArea(
          bottom: true,
          top: false,
          child: Container(
            width: double.infinity,
            height: double.infinity,
            padding: EdgeInsets.only(top: kToolbarHeight + ScreenUtil.getStatusBarH(context) + 1),
            decoration: const BoxDecoration(
              gradient: LinearGradient(
                colors: [
                  Color(0xFF091D44),
                  Color(0xFF245A8A),
                  Color(0xFF7F7CEC),
                ],
                begin: Alignment.topCenter,
                end: Alignment.bottomCenter,
              ),
            ),
            child: Column(
              children: [
                // 搜索的布局
                Container(
                  width: double.infinity,
                  height: 42,
                  margin: const EdgeInsets.symmetric(vertical: 15, horizontal: 15),
                  padding: const EdgeInsets.symmetric(vertical: 0, horizontal: 13.5),
                  decoration: BoxDecoration(
                    color: const Color(0xFF4DCFF6).withOpacity(0.2), // 设置背景颜色和不透明度
                    borderRadius: BorderRadius.circular(20.0), // 设置圆角
                  ),
                  child: Row(
                    children: [
                      const MyAssetImage(Assets.cptJobPickDateIcon, width: 15, height: 15),
                      MyTextView(
                        DateTimeUtils.formatDate(state.selectedDateTime, format: "yyyy-MM-dd"),
                        hint: "Select Date".tr,
                        textHintColor: ColorConstants.textGrayAECAE5,
                        fontSize: 15,
                        marginLeft: 9.5,
                        isFontRegular: true,
                        textColor: ColorConstants.textGrayAECAE5,
                      ),
                    ],
                  ).onTap(() {
                    controller.pickerSelectDate();
                  }),
                ),

                //添加用工请求按钮
                MyButton(
                  type: ClickType.throttle,
                  milliseconds: 500,
                  onPressed: () {
                    FocusScope.of(context).unfocus();
                    controller.gotoLabourRequestAddPage();
                  },
                  text: "Create New Job Request".tr,
                  textColor: ColorConstants.white,
                  fontSize: 16,
                  radius: 20,
                  backgroundColor: hexToColor("#FFBB1B"),
                  fontWeight: FontWeight.w500,
                ).marginOnly(left: 15, right: 15),

                Container(
                  width: double.infinity,
                  margin: const EdgeInsets.symmetric(vertical: 15, horizontal: 15),
                  decoration: BoxDecoration(
                    color: const Color(0xFF4DCFF6).withOpacity(0.2), // 设置背景颜色和不透明度
                    borderRadius: BorderRadius.circular(5.0), // 设置圆角
                  ),
                  child: Column(
                    children: [
                      Row(
                        children: [
                          MyTextView(
                            "Date".tr,
                            isFontBold: true,
                            fontSize: 16,
                            textAlign: TextAlign.center,
                            textColor: Colors.white,
                          ).expanded(flex: 5),
                          MyTextView(
                            "YY Circle".tr,
                            isFontBold: true,
                            fontSize: 16,
                            textAlign: TextAlign.right,
                            marginRight: 32,
                            textColor: Colors.white,
                          ).expanded(flex: 5),
                        ],
                      ).constrained(height: 45),

                      //分割线
                      const Divider(color: ColorConstants.dividerBar, height: 0.5),

                      //底部的数据
                      LoadStateLayout(
                        state: controller.loadingState,
                        errorMessage: controller.errorMessage,
                        errorRetry: () {
                          controller.retryRequest();
                        },
                        successWidget: Column(
                          children: state.datas.map((item) {
                            return LabourRequestItem(item: item);
                          }).toList(),
                        ).paddingOnly(top: 14, bottom: 7),
                      ).constrained(width: double.infinity, height: 291),
                    ],
                  ),
                ).constrained(minHeight: 336.5),
              ],
            ),
          ),
        ),
      );
    });
  }
}
